<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
xmlns="http://www.w3.org/1999/xhtml"
xmlns:sokop="http://sokop/tuzbe"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html"
	        doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
                doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" />
  <xsl:decimal-format name="nas" decimal-separator="," grouping-separator="."/>

  <xsl:template match="/">
    <html>
      <head>
        <link rel="stylesheet" type="text/css" href="/xsl/document.css" />
        <title>Tuzba</title>
      </head>
      <body>
        <xsl:if test="name(/*) = 'Tuzbe'">
          <xsl:for-each select="sokop:Tuzbe/sokop:Tuzba">
            <xsl:call-template name="Tuzba_Template"/>
            <hr class="end"/>
          </xsl:for-each>
        </xsl:if>
        <xsl:if test="name(/*) = 'Tuzba'">
          <xsl:for-each select="sokop:Tuzba">
            <xsl:call-template name="Tuzba_Template"/>
          </xsl:for-each>
        </xsl:if>
      </body>
    </html>
  </xsl:template>
  <xsl:template name="string-replace-all">
    <xsl:param name="text" />
    <xsl:param name="replace" />
    <xsl:param name="by" />
    <xsl:choose>
      <xsl:when test="contains($text, $replace)">
        <xsl:value-of select="substring-before($text,$replace)" />
        <xsl:value-of select="$by" />
        <xsl:call-template name="string-replace-all">
          <xsl:with-param name="text"
          select="substring-after($text,$replace)" />
          <xsl:with-param name="replace" select="$replace" />
          <xsl:with-param name="by" select="$by" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="Tuzba_Template">
    <xsl:variable name="smallcase" select="'abcdefghijklmnopqrstuvwxyz'" />
    <xsl:variable name="uppercase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'" />
    <xsl:variable name="vrijednostSpora"
        select='format-number(sokop:VrijednostSpora, "###.###0,00", "nas")'/>
    <div id="page" align="center">

      <xsl:variable name="nadleznost">
        <xsl:choose>

          <xsl:when test="sokop:Sud/sokop:Entitet='99'">
            Općinskog suda u Izmjšljenu
          </xsl:when>

          <xsl:when test="sokop:Sud/sokop:Sifra=99">
            Općinskog suda u Zenici
          </xsl:when>

          <xsl:when test="sokop:Sud/sokop:Sifra=85">
            Osnovnog suda u Doboju
          </xsl:when>

          <xsl:otherwise>
            DODATI_SUD
          </xsl:otherwise>

        </xsl:choose>
      </xsl:variable>

      <xsl:variable name="nadleznost_ski">
        <xsl:choose>
          <xsl:when test="sokop:Sud/sokop:Entitet='FEDERACIJA BOSNE I HERCEGOVINE'">
            <xsl:call-template name="string-replace-all">
              <xsl:with-param name="text" select="sokop:Sud/sokop:Naziv" />
              <xsl:with-param name="replace" select="'ski'" />
              <xsl:with-param name="by" select="'skog'" />
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="sokop:Sud/sokop:Entitet='REPUBLIKA SRPSKA'">
            <xsl:call-template name="string-replace-all">
              <xsl:with-param name="text" select="sokop:Sud/sokop:Naziv" />
              <xsl:with-param name="replace" select="'vni'" />
              <xsl:with-param name="by" select="'vnog'" />
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>DODATI_SUD</xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:variable name="nadleznost_a">
        <xsl:choose>
          <xsl:when test="sokop:Sud/sokop:Entitet='FEDERACIJA BOSNE I HERCEGOVINE'">
            <xsl:call-template name="string-replace-all">
              <xsl:with-param name="text" select="$nadleznost_ski" />
              <xsl:with-param name="replace" select="'sud'" />
              <xsl:with-param name="by" select="'suda'" />
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="sokop:Sud/sokop:Entitet='REPUBLIKA SRPSKA'">
            <xsl:call-template name="string-replace-all">
              <xsl:with-param name="text" select="$nadleznost_ski" />
              <xsl:with-param name="replace" select="'sud'" />
              <xsl:with-param name="by" select="'suda'" />
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>DODATI_SUD</xsl:otherwise>
        </xsl:choose>
      </xsl:variable>


      <xsl:if test="sokop:DatumPrijema">
        <div class="pecatTuzba">
          Primljeno u sud:
          <xsl:value-of select="sokop:DatumPrijema"/>
        </div>
      </xsl:if>

      <div id = "header" align="left">
        <xsl:if test= "sokop:Potpis">
          <ul>
            <li>
              Digitalni potpis JKP:&#xa0;
            </li>
            <xsl:value-of select="sokop:Potpis/sokop:Potpisnik"/>
            <br/>
            <li>
              DN:&#xa0;
            </li>
            <xsl:value-of select="sokop:Potpis/sokop:DN"/>
            <br/>
            <li>
              Datum:&#xa0;
            </li>
            <xsl:value-of select="sokop:Potpis/sokop:VrijemePotpisa"/>
          </ul>
        </xsl:if>
        <br/>
        <ul>
          <li2>
            <xsl:value-of select="sokop:Tuzilac/sokop:Naziv"/>
          </li2>
          <br/>
          <li>
            Broj: <xsl:value-of select="sokop:BrojTuzbe"/>
          </li>

          <br/>
          <li>
            <xsl:value-of select="sokop:Tuzilac/sokop:Adresa/sokop:Mjesto"/>,&#xa0;
            <xsl:value-of select="sokop:DatumTuzbe"/> godine
          </li>
          <br/>
          <li>
            <xsl:value-of select="sokop:Sud/sokop:Naziv"/>
          </li>
        </ul>
      </div>
      <div id = "title" align="left">

        <strong>Tužitelj: </strong>	<xsl:value-of select="sokop:Tuzilac/sokop:Naziv"/>,
        <xsl:value-of select="sokop:Tuzilac/sokop:Adresa/sokop:Ulica"/>&#xa0;
        <xsl:value-of select="sokop:Tuzilac/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
        <xsl:value-of select="sokop:Tuzilac/sokop:Adresa/sokop:Mjesto"/>&#xa0;, zastupano po  – <xsl:value-of select="sokop:Tuzilac/sokop:Zastupnik/sokop:Ime"/>&#xa0;
        <xsl:value-of select="sokop:Tuzilac/sokop:Zastupnik/sokop:Prezime"/>,&#xa0;<xsl:value-of select="sokop:Tuzilac/sokop:Zastupnik/sokop:Funkcija"/> <br/><br/>
        <strong>Tuženi: </strong>
        <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'F'">
          <xsl:value-of select="sokop:Tuzeni/sokop:Ime"/>&#xa0;
          <xsl:choose>
            <xsl:when test="sokop:Tuzeni/sokop:ImeRoditelja">
              <xsl:if test="not(sokop:Tuzeni/sokop:ImeRoditelja='')">
                (
                <xsl:value-of select="sokop:Tuzeni/sokop:ImeRoditelja"/>
                )&#xa0;
              </xsl:if>
            </xsl:when>
          </xsl:choose>
          <xsl:value-of select="sokop:Tuzeni/sokop:Prezime"/>&#xa0;iz&#xa0;<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;,&#xa0;stalno nastanjen u ulici:
          <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Ulica"/>&#xa0;BR.
          <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
          <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;
        </xsl:if>
        <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'P'">
          <xsl:value-of select="sokop:Tuzeni/sokop:Naziv"/>,&#xa0;
          <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Ulica"/>&#xa0;
          <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
          <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;
        </xsl:if><br/><br/>
        <strong>Radi: </strong>Naplate novčanog potraživanja<br/><br/>
        <strong> Vrijednost spora:&#xa0;</strong><xsl:value-of select='$vrijednostSpora'/>&#xa0;KM<br/><br/>
        <xsl:if test="not(sokop:ZakonskiOsnov='')">
          Pravni osnov ovog tužbenog zahtjeva predstavlja <xsl:value-of select="sokop:ZakonskiOsnov"/>
        </xsl:if><br/><br/>
        Osnov za nadležnost ovog suda predstavlja član 27 i 28 Zakona o parničnom postupku RS

        <!--	<div align="center">
					<xsl:value-of select="sokop:Sud/sokop:Naziv"/>
				</div> -->

        <h3>TUŽBA</h3>
        <ul>
          <!--	<li>
						<strong>TUŽILAC:</strong>&#xa0;
					</li>
					<xsl:value-of select="sokop:Tuzilac/sokop:Naziv"/>,&#xa0;
					<xsl:value-of select="sokop:Tuzilac/sokop:Adresa/sokop:Ulica"/>&#xa0;
					<xsl:value-of select="sokop:Tuzilac/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
					<xsl:value-of select="sokop:Tuzilac/sokop:Adresa/sokop:Mjesto"/>&#xa0;
					<br/>-->
          <!--<li>
						<strong>TUŽENI:</strong>&#xa0;
					</li>
					<xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'F'">
						<xsl:value-of select="sokop:Tuzeni/sokop:Ime"/>&#xa0;
						<xsl:choose>
							<xsl:when test="sokop:Tuzeni/sokop:ImeRoditelja">
								<xsl:if test="not(sokop:Tuzeni/sokop:ImeRoditelja='')">
									(
									<xsl:value-of select="sokop:Tuzeni/sokop:ImeRoditelja"/>
									)&#xa0;
								</xsl:if>
							</xsl:when>
						</xsl:choose>
						<xsl:value-of select="sokop:Tuzeni/sokop:Prezime"/>,&#xa0;
						<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Ulica"/>&#xa0;BR.
						<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
						<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;
					</xsl:if>
					<xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'P'">
						<xsl:value-of select="sokop:Tuzeni/sokop:Naziv"/>,&#xa0;
						<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Ulica"/>&#xa0;
						<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
						<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;
					</xsl:if>-->
          <!--<br/>
					<li>
						<strong>RADI:</strong>&#xa0;
					</li>Naplate novčanog potraživanja
					<br/>
					<li>
						<strong> VRIJEDNOST SPORA&#xa0;</strong>
					</li>
					<strong>
						<xsl:value-of select='$vrijednostSpora'/>&#xa0;KM
					</strong>-->

        </ul>
      </div>
      <div id="content">
        <xsl:variable name="takseSentence">
          <xsl:if test="sokop:TaksaNaTuzbuPostoji = 'true' or sokop:TaksaNaPresuduPostoji='true'">
            <xsl:if test="sokop:TaksaNaTuzbuPostoji = 'true'">
              <xsl:if test="sokop:TaksaNaPresuduPostoji = 'true'">
                <xsl:text>uz naknadu troškova parničnog postupka u visini takse na tužbu i presudu</xsl:text>
              </xsl:if>
              <xsl:if test="sokop:TaksaNaPresuduPostoji = 'false'">
                <xsl:text>uz naknadu troškova parničnog postupka u visini takse na tužbu</xsl:text>
              </xsl:if>
            </xsl:if>
            <xsl:if test="sokop:TaksaNaTuzbuPostoji = 'false'">
              <xsl:if test="sokop:TaksaNaPresuduPostoji = 'true'">
                <xsl:text>uz naknadu troškova parničnog postupka u visini takse na presudu</xsl:text>
              </xsl:if>
            </xsl:if>

          </xsl:if>
        </xsl:variable>


        <p>Tužitelj je sa tuženim zasnovao poslovni odnos na način da je za usluge iz svoje registrovane pretežne djelatnosti, uredno ispostavljao račune . </p>
        <p>
          Dokaz:<xsl:value-of select="sokop:Dokaz"/><br/>
          <xsl:if test="not(sokop:BrojUgovora='')">
            <p>
              Ugovor broj: <xsl:value-of select='sokop:BrojUgovora'/>, zaključen dana <xsl:value-of select='sokop:DatumUgovora'/> godine.
            </p>
          </xsl:if>
          <xsl:for-each select="sokop:IzvadakIzPoslovneKnjige/sokop:Stavke/sokop:DospijecePoOsnovuRacuna">
            Račun broj: <xsl:value-of select='sokop:BrojRacuna'/> <xsl:variable name="iznosRacuna" select="sokop:Duguje"/>
            <xsl:variable name="iznosUplata" select='(sum(../sokop:Uplata[sokop:BrojRacuna=$brojRacuna]/sokop:Potrazuje))'/>
            na iznos <xsl:value-of select='format-number(($iznosRacuna - $iznosUplata), "###.###,00", "nas")'/> KM od <xsl:value-of select="sokop:DatumRacuna"/> godine, <br/>
          </xsl:for-each>
        </p>
        <p>Tužitelj je svoje obaveze iz tako zasnovanog poslovnog odnosa izvršavao uredno i na vrijeme. Kako tuženi još uvijek nije isplatio dugovani iznos, a ne pokazuje ni namjeru da to učini, to tužitelj predlaže da sud na osnovu predloženih činjenica i provedenih dokaza, nakon održane glavne rasprave donese sljedeću :</p>
        <br/>
        <h3>PRESUDU</h3>
        <br/>
        <xsl:choose>
          <xsl:when test="sokop:TipKamate = 'OdDatumaPodnosenjaTuzbe'">
            <p>
              Obavezuje se tuženi
              <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'F'">
                <xsl:value-of select="sokop:Tuzeni/sokop:Ime"/>&#xa0;
                <xsl:choose>
                  <xsl:when test="sokop:Tuzeni/sokop:ImeRoditelja">
                    <xsl:if test="not(sokop:Tuzeni/sokop:ImeRoditelja='')">
                      (
                      <xsl:value-of select="sokop:Tuzeni/sokop:ImeRoditelja"/>
                      )&#xa0;
                    </xsl:if>
                  </xsl:when>
                </xsl:choose>
                <xsl:value-of select="sokop:Tuzeni/sokop:Prezime"/>&#xa0;iz&#xa0;<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;,&#xa0;stalno nastanjen u ulici:
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Ulica"/>&#xa0;BR.
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;
              </xsl:if>
              <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'P'">
                <xsl:value-of select="sokop:Tuzeni/sokop:Naziv"/>
              </xsl:if>
              da tužitelju <xsl:value-of select="sokop:Tuzilac/sokop:Naziv"/> isplati iznos od <xsl:value-of select='$vrijednostSpora'/> KM,
              uvećan za zakonske kamate koje počinju teći od <xsl:value-of select="sokop:DatumTuzbe"/> godine, kao dana podnošenja tužbe,
              pa sve do isplate,
              <xsl:value-of select="$takseSentence" />
              sve u roku od 15 dana pod prijetnjom prinudnog izvršenja.
            </p>
          </xsl:when>
          <xsl:when test="sokop:TipKamate = 'OdDatumaDospijecaRacuna'">
            <p>
              Obavezuje se tuženi
              <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'F'">
                <xsl:value-of select="sokop:Tuzeni/sokop:Ime"/>&#xa0;
                <xsl:choose>
                  <xsl:when test="sokop:Tuzeni/sokop:ImeRoditelja">
                    <xsl:if test="not(sokop:Tuzeni/sokop:ImeRoditelja='')">
                      (
                      <xsl:value-of select="sokop:Tuzeni/sokop:ImeRoditelja"/>
                      )&#xa0;
                    </xsl:if>
                  </xsl:when>
                </xsl:choose>
                <xsl:value-of select="sokop:Tuzeni/sokop:Prezime"/>&#xa0;iz&#xa0;<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;,&#xa0;stalno nastanjen u ulici:
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Ulica"/>&#xa0;BR.
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;
              </xsl:if>
              <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'P'">
                <xsl:value-of select="sokop:Tuzeni/sokop:Naziv"/>
              </xsl:if>
              da tužitelju  <xsl:value-of select="sokop:Tuzilac/sokop:Naziv"/> isplati iznos od <xsl:value-of select='$vrijednostSpora'/> KM, uvećan za zakonske kamate koje počinju teći od dana dospijeća svakog pojedinačnog računa i to : <br/><br/>
              <xsl:for-each select="sokop:IzvadakIzPoslovneKnjige/sokop:Stavke/sokop:DospijecePoOsnovuRacuna">
                &#xa0;•&#xa0;&#xa0;&#xa0;


                Račun broj <xsl:variable name="brojRacuna" select="sokop:BrojRacuna"/> <xsl:value-of select="sokop:BrojRacuna"/>,
                <xsl:variable name="iznosRacuna" select="sokop:Duguje"/>
                <xsl:variable name="iznosUplata" select='(sum(../sokop:Uplata[sokop:BrojRacuna=$brojRacuna]/sokop:Potrazuje))'/>
                na iznos <xsl:value-of select='format-number(($iznosRacuna - $iznosUplata), "###.###,00", "nas")'/> KM počev od <xsl:value-of select="sokop:DatumDospijeca"/> godine,

                <br/><br/>
              </xsl:for-each>
              pa sve do isplate, <xsl:value-of select="$takseSentence" /> sve u roku od 15 dana pod prijetnjom prinudnog izvršenja.
            </p>
          </xsl:when>
          <xsl:when test="sokop:TipKamate = 'BezKamate'">
            <p>
              Obavezuje se tuženi
              <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'F'">
                <xsl:value-of select="sokop:Tuzeni/sokop:Ime"/>&#xa0;
                <xsl:choose>
                  <xsl:when test="sokop:Tuzeni/sokop:ImeRoditelja">
                    <xsl:if test="not(sokop:Tuzeni/sokop:ImeRoditelja='')">
                      (
                      <xsl:value-of select="sokop:Tuzeni/sokop:ImeRoditelja"/>
                      )&#xa0;
                    </xsl:if>
                  </xsl:when>
                </xsl:choose>
                <xsl:value-of select="sokop:Tuzeni/sokop:Prezime"/>&#xa0;iz&#xa0;<xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;,&#xa0;stalno nastanjen u ulici:
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Ulica"/>&#xa0;BR.
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:BrojUlice"/>,&#xa0;
                <xsl:value-of select="sokop:Tuzeni/sokop:Adresa/sokop:Mjesto"/>&#xa0;
              </xsl:if>
              <xsl:if test="sokop:Tuzeni/sokop:SifraTipaLica = 'P'">
                <xsl:value-of select="sokop:Tuzeni/sokop:Naziv"/>
              </xsl:if>
              da tužitelju <xsl:value-of select="sokop:Tuzilac/sokop:Naziv"/> isplati iznos od <xsl:value-of select='$vrijednostSpora'/> KM <xsl:value-of select="$takseSentence" /> sve u roku od 15 dana pod prijetnjom prinudnog izvršenja.
            </p>
          </xsl:when>
        </xsl:choose>
        <p>Konačno, Tužitelj u smislu člana 182 ZPP-a RS predlaže, da ukoliko Tuženi kome će tužba biti dostavljena, ne dostavi pismeni odgovor u zakonskom roku od 30 dana, sud usvoji tužbeni zahtjev i donese presudu zbog propuštanja. </p>
        <p>
          Nadležnost

          <xsl:value-of select='$nadleznost_a'/>
          se zasniva na odredbama člana 27 i 28 Zakona o parničnom postupku.
        </p>
        <p>
          Tuženi tužiocu na osnovu
          <xsl:value-of select="sokop:ZakonskiOsnov"/>
          duguje iznos od
          <xsl:value-of select='$vrijednostSpora'/> KM.
        </p>
        <xsl:if test="sokop:Dokaz != ''">
          <p>
            Dokaz:&#xa0;
            <xsl:value-of select="sokop:Dokaz"/>
          </p>
        </xsl:if>
        <p>
          Prema stanju uplata tuženi nije izmirio svoje  obaveze  koje na dan
          <xsl:value-of select="sokop:DatumTuzbe"/>
          iznose
          <xsl:value-of select='$vrijednostSpora'/> KM,
          prema izvodu iz poslovne knjige  koji je sastavni dio ove tužbe, a što je  bio dužan da učini.
        </p>

        <p>
          Kako iz naprijed navedenog proizlazi osnovanost tužbenog zahtjeva, tužilac predlaže Sudu da donese presudu
          zbog propuštanja ukoliko budu ispunjeni propisani uslovi za donošenje iste u skladu sa članom 182.
          Zakona o parničnom postupku  ili
          da sud nakon provedenog parničnog postupka donese:
        </p>
        <br/>
        <h3>PRESUDU</h3>
        <br/>
        <p>
          Usvaja se tužbeni zahtjev tužioca, te se tuženi obavezuje da tužiocu isplati dug u iznosu od
          <xsl:value-of select='$vrijednostSpora'/> KM
          <xsl:choose>
            <xsl:when test="sokop:TipKamate = 'OdDatumaPodnosenjaTuzbe'">
              sa zakonskom zateznom kamatom od dana podnošenja tužbe do dana isplate
            </xsl:when>
            <xsl:when test="sokop:TipKamate = 'OdDatumaDospijecaRacuna'">
              sa zakonskom zateznom kamatom od dana dospijeća potraživanja do dana isplate, i to kako slijedi:
              <br/>

              <xsl:for-each select="sokop:IzvadakIzPoslovneKnjige/sokop:Stavke/sokop:DospijecePoOsnovuRacuna">
                &#xa0;•&#xa0;&#xa0;&#xa0;

                <xsl:variable name="brojRacuna" select="sokop:BrojRacuna"/>
                <xsl:variable name="iznosRacuna" select="sokop:Duguje"/>
                <xsl:variable name="iznosUplata" select='(sum(../sokop:Uplata[sokop:BrojRacuna=$brojRacuna]/sokop:Potrazuje))'/>
                na iznos <xsl:value-of select='format-number(($iznosRacuna - $iznosUplata), "###.###,00", "nas")'/> KM od <xsl:value-of select="sokop:DatumDospijeca"/> godine,

                <br/>
              </xsl:for-each>
            </xsl:when>
            <xsl:when test="sokop:Kamata/sokop:TipKamate = 'BezKamate'">

            </xsl:when>
          </xsl:choose>
          uz naknadu troškova parničnog postupka i to
          u visini takse na tužbu i presudu, sve u roku od 15 dana pod
          prijetnjom izvršenja.
        </p>
        <xsl:if test="(sokop:TaksaNaTuzbu > 0) or (sokop:TaksaNaPresudu > 0)">
          <div align="left">
            TROŠKOVNIK
            <br/>
            <br/>
            <table>
              <xsl:if test="sokop:TaksaNaTuzbu >0">
                <tr>
                  <td>
                    •&#xa0;&#xa0;&#xa0;Taksa na tužbu
                  </td>
                  <td>

                  </td>
                </tr>
              </xsl:if>
              <xsl:if test="sokop:TaksaNaPresudu >0">
                <tr>
                  <td>
                    •&#xa0;&#xa0;&#xa0;Taksa na presudu
                  </td>
                  <td>

                  </td>
                </tr>
              </xsl:if>


              <xsl:for-each select="sokop:TroskoviTuzioca/sokop:Trosak">
                <tr>
                  <td sytle="border-right-style:none;border-left-style: none; border-bottom-style: none;border-top-style: none;">
                    •&#xa0;&#xa0;
                    <xsl:value-of select="sokop:Opis"/>
                  </td>
                  <td style="padding-left:20px">
                    <xsl:value-of select="sokop:Iznos"/> KM
                  </td>
                </tr>
              </xsl:for-each>
            </table>
          </div>
        </xsl:if>
      </div>
      <div id = "footer">
        <p class="signature">
          <strong>ZA TUŽIOCA:</strong>
          <br/>
          <xsl:value-of select="sokop:Tuzilac/sokop:Zastupnik/sokop:Ime"/>&#xa0;
          <xsl:value-of select="sokop:Tuzilac/sokop:Zastupnik/sokop:Prezime"/>,
          <xsl:value-of select="sokop:Tuzilac/sokop:Zastupnik/sokop:Funkcija"/>
        </p>
      </div>
    </div>

  </xsl:template>
</xsl:stylesheet>
